@@ -33,7 +33,6 @@ from typing import Any, Collection, Dict, List, Optional, Set, Tuple, Type, Unio
 import jsonschema
 from packaging.specifiers import SpecifierSet
 
-from aea import AEA_DIR
 from aea.aea import AEA
 from aea.components.base import Component, load_aea_package
 from aea.components.loader import load_component_from_config
@@ -55,16 +54,20 @@ from aea.configurations.constants import (
     DEFAULT_CONNECTION,
     DEFAULT_LEDGER,
     DEFAULT_PROTOCOL,
+)
+from aea.configurations.constants import (
+    DEFAULT_SEARCH_SERVICE_ADDRESS as _DEFAULT_SEARCH_SERVICE_ADDRESS,
+)
+from aea.configurations.constants import (
     DEFAULT_SKILL,
+    SIGNING_PROTOCOL,
+    STATE_UPDATE_PROTOCOL,
 )
 from aea.configurations.loader import ConfigLoader, load_component_configuration
 from aea.configurations.pypi import is_satisfiable, merge_dependencies
 from aea.crypto.helpers import verify_or_create_private_keys
 from aea.crypto.wallet import Wallet
 from aea.decision_maker.base import DecisionMakerHandler
-from aea.decision_maker.default import (
-    DecisionMakerHandler as DefaultDecisionMakerHandler,
-)
 from aea.exceptions import AEAException
 from aea.helpers.base import find_topological_order, load_env_file, load_module
 from aea.helpers.exception_policy import ExceptionPolicyEnum
@@ -225,7 +228,7 @@ class _DependenciesManager:
     def install_dependencies(self) -> None:
         """Install extra dependencies for components."""
         for name, d in self.pypi_dependencies.items():
-            install_dependency(name, d)
+            install_dependency(name, d, _default_logger)
 
 
 class AEABuilder(WithLogger):  # pylint: disable=too-many-public-methods
@@ -279,26 +282,26 @@ class AEABuilder(WithLogger):  # pylint: disable=too-many-public-methods
     DEFAULT_AGENT_ACT_PERIOD = 0.05  # seconds
     DEFAULT_EXECUTION_TIMEOUT = 0
     DEFAULT_MAX_REACTIONS = 20
-    DEFAULT_DECISION_MAKER_HANDLER_CLASS: Type[
-        DecisionMakerHandler
-    ] = DefaultDecisionMakerHandler
     DEFAULT_SKILL_EXCEPTION_POLICY = ExceptionPolicyEnum.propagate
     DEFAULT_CONNECTION_EXCEPTION_POLICY = ExceptionPolicyEnum.propagate
     DEFAULT_LOOP_MODE = "async"
     DEFAULT_RUNTIME_MODE = "threaded"
-    DEFAULT_SEARCH_SERVICE_ADDRESS = "fetchai/soef:*"
+    DEFAULT_SEARCH_SERVICE_ADDRESS = _DEFAULT_SEARCH_SERVICE_ADDRESS
 
     loader = ConfigLoader.from_configuration_type(PackageType.AGENT)
 
     # pylint: disable=attribute-defined-outside-init
 
-    def __init__(self, with_default_packages: bool = True):
+    def __init__(
+        self, with_default_packages: bool = True, registry_dir: str = "packages"
+    ):
         """
         Initialize the builder.
 
         :param with_default_packages: add the default packages.
         """
         WithLogger.__init__(self, logger=_default_logger)
+        self.registry_dir = os.path.join(os.getcwd(), registry_dir)
         self._with_default_packages = with_default_packages
         self._reset(is_full_reset=True)
 
@@ -508,11 +511,24 @@ class AEABuilder(WithLogger):  # pylint: disable=too-many-public-methods
     def _add_default_packages(self) -> None:
         """Add default packages."""
         # add default protocol
-        self.add_protocol(Path(AEA_DIR, "protocols", DEFAULT_PROTOCOL.name))
+        self.add_protocol(
+            Path(self.registry_dir, "fetchai", "protocols", DEFAULT_PROTOCOL.name)
+        )
+        # add signing protocol
+        self.add_protocol(
+            Path(self.registry_dir, "fetchai", "protocols", SIGNING_PROTOCOL.name)
+        )
+        # add state update protocol
+        self.add_protocol(
+            Path(self.registry_dir, "fetchai", "protocols", STATE_UPDATE_PROTOCOL.name)
+        )
+
         # add stub connection
-        self.add_connection(Path(AEA_DIR, "connections", DEFAULT_CONNECTION.name))
+        self.add_connection(
+            Path(self.registry_dir, "fetchai", "connections", DEFAULT_CONNECTION.name)
+        )
         # add error skill
-        self.add_skill(Path(AEA_DIR, "skills", DEFAULT_SKILL.name))
+        self.add_skill(Path(self.registry_dir, "fetchai", "skills", DEFAULT_SKILL.name))
 
     def _check_can_remove(self, component_id: ComponentId) -> None:
         """
@@ -942,17 +958,15 @@ class AEABuilder(WithLogger):  # pylint: disable=too-many-public-methods
             else self.DEFAULT_MAX_REACTIONS
         )
 
-    def _get_decision_maker_handler_class(self) -> Type[DecisionMakerHandler]:
+    def _get_decision_maker_handler_class(
+        self,
+    ) -> Optional[Type[DecisionMakerHandler]]:
         """
         Return the decision maker handler class.
 
         :return: decision maker handler class
         """
-        return (
-            self._decision_maker_handler_class
-            if self._decision_maker_handler_class is not None
-            else self.DEFAULT_DECISION_MAKER_HANDLER_CLASS
-        )
+        return self._decision_maker_handler_class
 
     def _get_skill_exception_policy(self) -> ExceptionPolicyEnum:
         """
@@ -1090,7 +1104,7 @@ class AEABuilder(WithLogger):  # pylint: disable=too-many-public-methods
                 )
 
     @staticmethod
-    def _find_component_directory_from_component_id(
+    def find_component_directory_from_component_id(
         aea_project_directory: Path, component_id: ComponentId
     ) -> Path:
         """Find a component directory from component id."""
@@ -1213,13 +1227,9 @@ class AEABuilder(WithLogger):  # pylint: disable=too-many-public-methods
                 ComponentId(ComponentType.CONTRACT, p_id)
                 for p_id in agent_configuration.contracts
             ],
-            [
-                ComponentId(ComponentType.CONNECTION, p_id)
-                for p_id in agent_configuration.connections
-            ],
         )
         for component_id in component_ids:
-            component_path = self._find_component_directory_from_component_id(
+            component_path = self.find_component_directory_from_component_id(
                 aea_project_path, component_id
             )
             self.add_component(
@@ -1228,6 +1238,25 @@ class AEABuilder(WithLogger):  # pylint: disable=too-many-public-methods
                 skip_consistency_check=skip_consistency_check,
             )
 
+        connection_ids = [
+            ComponentId(ComponentType.CONNECTION, p_id)
+            for p_id in agent_configuration.connections
+        ]
+        if len(connection_ids) != 0:
+            connection_import_order = self._find_import_order(
+                connection_ids, aea_project_path, skip_consistency_check
+            )
+
+            for connection_id in connection_import_order:
+                component_path = self.find_component_directory_from_component_id(
+                    aea_project_path, connection_id
+                )
+                self.add_component(
+                    connection_id.component_type,
+                    component_path,
+                    skip_consistency_check=skip_consistency_check,
+                )
+
         skill_ids = [
             ComponentId(ComponentType.SKILL, p_id)
             for p_id in agent_configuration.skills
@@ -1240,7 +1269,7 @@ class AEABuilder(WithLogger):  # pylint: disable=too-many-public-methods
             skill_ids, aea_project_path, skip_consistency_check
         )
         for skill_id in skill_import_order:
-            component_path = self._find_component_directory_from_component_id(
+            component_path = self.find_component_directory_from_component_id(
                 aea_project_path, skill_id
             )
             self.add_component(
@@ -1254,45 +1283,50 @@ class AEABuilder(WithLogger):  # pylint: disable=too-many-public-methods
 
     def _find_import_order(
         self,
-        skill_ids: List[ComponentId],
+        component_ids: List[ComponentId],
         aea_project_path: Path,
         skip_consistency_check: bool,
     ) -> List[ComponentId]:
-        """Find import order for skills.
+        """Find import order for skills/connections.
 
-        We need to handle skills separately, since skills can depend on each other.
+        We need to handle skills and connections separately, since skills/connections can depend on each other.
 
         That is, we need to:
-        - load the skill configurations to find the import order
+        - load the skill/connection configurations to find the import order
         - detect if there are cycles
-        - import skills from the leaves of the dependency graph, by finding a topological ordering.
+        - import skills/connections from the leaves of the dependency graph, by finding a topological ordering.
         """
         # the adjacency list for the inverse dependency graph
         dependency_to_supported_dependencies: Dict[
             ComponentId, Set[ComponentId]
         ] = defaultdict(set)
-        for skill_id in skill_ids:
-            component_path = self._find_component_directory_from_component_id(
-                aea_project_path, skill_id
+        for component_id in component_ids:
+            component_path = self.find_component_directory_from_component_id(
+                aea_project_path, component_id
             )
-            configuration = cast(
-                SkillConfig,
-                load_component_configuration(
-                    skill_id.component_type, component_path, skip_consistency_check
-                ),
+            configuration = load_component_configuration(
+                component_id.component_type, component_path, skip_consistency_check
             )
 
-            if skill_id not in dependency_to_supported_dependencies:
-                dependency_to_supported_dependencies[skill_id] = set()
-            for dependency in configuration.skills:
+            if component_id not in dependency_to_supported_dependencies:
+                dependency_to_supported_dependencies[component_id] = set()
+            if isinstance(configuration, SkillConfig):
+                dependencies, component_type = configuration.skills, "skills"
+            elif isinstance(configuration, ConnectionConfig):
+                dependencies, component_type = configuration.connections, "connections"
+            else:
+                raise AEAException("Not a valid configuration type.")  # pragma: nocover
+            for dependency in dependencies:
                 dependency_to_supported_dependencies[
                     ComponentId(ComponentType.SKILL, dependency)
-                ].add(skill_id)
+                ].add(component_id)
 
         try:
             order = find_topological_order(dependency_to_supported_dependencies)
         except ValueError:
-            raise AEAException("Cannot load skills, there is a cyclic dependency.")
+            raise AEAException(
+                f"Cannot load {component_type}, there is a cyclic dependency."
+            )
 
         return order
 
