@@ -20,13 +20,12 @@
 """Implementation of the 'aea generate' subcommand."""
 
 import os
-from typing import cast
 
 import click
 
-from aea.cli.fingerprint import _fingerprint_item
+from aea.cli.fingerprint import fingerprint_item
 from aea.cli.utils.context import Context
-from aea.cli.utils.decorators import check_aea_project, clean_after
+from aea.cli.utils.decorators import check_aea_project, clean_after, pass_ctx
 from aea.cli.utils.loggers import logger
 from aea.configurations.base import (
     DEFAULT_AEA_CONFIG_FILE,
@@ -40,23 +39,21 @@ from aea.protocols.generator.common import load_protocol_specification
 @click.group()
 @click.pass_context
 @check_aea_project
-def generate(click_context):  # pylint: disable=unused-argument
+def generate(click_context: click.core.Context):  # pylint: disable=unused-argument
     """Generate a resource for the agent."""
 
 
 @generate.command()
 @click.argument("protocol_specification_path", type=str, required=True)
-@click.pass_context
-def protocol(click_context, protocol_specification_path: str):
+@pass_ctx
+def protocol(ctx: Context, protocol_specification_path: str):
     """Generate a protocol based on a specification and add it to the configuration file and agent."""
-    _generate_item(click_context, "protocol", protocol_specification_path)
+    _generate_item(ctx, "protocol", protocol_specification_path)
 
 
 @clean_after
-def _generate_item(click_context, item_type, specification_path):
+def _generate_item(ctx: Context, item_type: str, specification_path: str):
     """Generate an item based on a specification and add it to the configuration file and agent."""
-    ctx = cast(Context, click_context.obj)
-
     # Get existing items
     existing_id_list = getattr(ctx.agent_config, "{}s".format(item_type))
     existing_item_list = [public_id.name for public_id in existing_id_list]
@@ -135,4 +132,4 @@ def _generate_item(click_context, item_type, specification_path):
             + str(e)
         )
 
-    _fingerprint_item(click_context, "protocol", protocol_spec.public_id)
+    fingerprint_item(ctx, "protocol", protocol_spec.public_id)
