@@ -36,7 +36,7 @@ from aea.exceptions import AEAEnforceError
 from aea.helpers.logging import WithLogger
 
 
-logger = logging.getLogger(__name__)
+_default_logger = logging.getLogger(__name__)
 
 
 class Component(ABC, WithLogger):
@@ -141,5 +141,5 @@ def load_aea_package(configuration: ComponentConfiguration) -> None:
         spec = importlib.util.spec_from_file_location(import_path, subpackage_init_file)
         module = importlib.util.module_from_spec(spec)
         sys.modules[import_path] = module
-        logger.debug(f"loading {import_path}: {module}")
+        _default_logger.debug(f"loading {import_path}: {module}")
         spec.loader.exec_module(module)  # type: ignore
