@@ -18,7 +18,6 @@
 # ------------------------------------------------------------------------------
 
 """This module contains utilities for loading components."""
-import logging
 import re
 from typing import Dict, Type
 
@@ -31,9 +30,6 @@ from aea.protocols.base import Protocol
 from aea.skills.base import Skill
 
 
-logger = logging.getLogger(__name__)
-
-
 def component_type_to_class(component_type: ComponentType) -> Type[Component]:
     """
     Get the component class from the component type.
