@@ -37,11 +37,11 @@ from aea.connections.base import Connection, ConnectionStates
 from aea.exceptions import enforce
 from aea.mail.base import Envelope, EnvelopeContext
 from aea.protocols.base import Message
-from aea.protocols.default.message import DefaultMessage
 from aea.protocols.dialogue.base import Dialogue as BaseDialogue
 from aea.protocols.dialogue.base import DialogueLabel as BaseDialogueLabel
 
 from packages.fetchai.connections.oef.object_translator import OEFObjectTranslator
+from packages.fetchai.protocols.default.message import DefaultMessage
 from packages.fetchai.protocols.oef_search.dialogues import (
     OefSearchDialogue as BaseOefSearchDialogue,
 )
@@ -60,7 +60,7 @@ RESPONSE_MESSAGE_ID = MESSAGE_ID + 1
 STUB_MESSAGE_ID = 0
 STUB_DIALOGUE_ID = 0
 DEFAULT_OEF = "oef"
-PUBLIC_ID = PublicId.from_str("fetchai/oef:0.11.0")
+PUBLIC_ID = PublicId.from_str("fetchai/oef:0.12.0")
 
 
 class OefSearchDialogue(BaseOefSearchDialogue):
@@ -413,7 +413,7 @@ class OEFChannel(OEFAgent):
                 )
                 raise ValueError("Cannot send message.")
 
-        if envelope.protocol_id == PublicId.from_str("fetchai/oef_search:0.8.0"):
+        if envelope.protocol_id == OefSearchMessage.protocol_id:
             self.send_oef_message(envelope)
         else:
             self.send_default_message(envelope)
