@@ -42,7 +42,7 @@ SUCCESS = 200
 NOT_FOUND = 404
 REQUEST_TIMEOUT = 408
 SERVER_ERROR = 500
-PUBLIC_ID = PublicId.from_str("fetchai/webhook:0.8.0")
+PUBLIC_ID = PublicId.from_str("fetchai/webhook:0.9.0")
 
 _default_logger = logging.getLogger("aea.packages.fetchai.connections.webhook")
 
@@ -205,7 +205,7 @@ class WebhookChannel:
             url=str(request.url),
             version=version,
             headers=json.dumps(dict(request.headers)),
-            bodyy=payload_bytes if payload_bytes is not None else b"",
+            body=payload_bytes if payload_bytes is not None else b"",
         )
         envelope = Envelope(
             to=http_message.to,
