@@ -22,7 +22,7 @@
 import logging
 from typing import Set, Tuple, cast
 
-from aea.configurations.base import ProtocolId
+from aea.configurations.base import PublicId
 from aea.exceptions import AEAEnforceError, enforce
 from aea.protocols.base import Message
 
@@ -40,7 +40,7 @@ DEFAULT_BODY_SIZE = 4
 class MlTradeMessage(Message):
     """A protocol for trading data for training and prediction purposes."""
 
-    protocol_id = ProtocolId.from_str("fetchai/ml_trade:0.7.0")
+    protocol_id = PublicId.from_str("fetchai/ml_trade:0.8.0")
 
     Description = CustomDescription
 
@@ -180,7 +180,7 @@ class MlTradeMessage(Message):
             )
 
             # Check correct contents
-            actual_nb_of_contents = len(self.body) - DEFAULT_BODY_SIZE
+            actual_nb_of_contents = len(self._body) - DEFAULT_BODY_SIZE
             expected_nb_of_contents = 0
             if self.performative == MlTradeMessage.Performative.CFP:
                 expected_nb_of_contents = 1
