@@ -18,3 +18,8 @@
 # ------------------------------------------------------------------------------
 
 """This module contains an example of skill for an AEA."""
+
+from aea.configurations.base import PublicId
+
+
+PUBLIC_ID = PublicId.from_str("fetchai/echo:0.10.0")
