@@ -26,6 +26,7 @@ from aea.exceptions import AEAEnforceError, enforce
 from aea.helpers.search.models import Location
 from aea.skills.base import Model
 
+from packages.fetchai.contracts.erc1155.contract import PUBLIC_ID as CONTRACT_ID
 from packages.fetchai.skills.tac_control.helpers import (
     generate_currency_id_to_name,
     generate_good_id_to_name,
@@ -123,6 +124,7 @@ class Parameters(Model):
         }
 
         super().__init__(**kwargs)
+        self._contract_id = str(CONTRACT_ID)
         self._currency_id_to_name = generate_currency_id_to_name(
             self.nb_currencies, self.currency_ids
         )
@@ -177,6 +179,11 @@ class Parameters(Model):
             raise AEAEnforceError("Contract address already provided.")
         self._contract_address = contract_address
 
+    @property
+    def contract_id(self) -> str:
+        """Get the contract id."""
+        return self._contract_id
+
     @property
     def is_contract_deployed(self) -> bool:
         """Check if there is a deployed instance of the contract."""
