@@ -65,6 +65,9 @@ _.latest  # unused property (aea/configurations/base.py:384)
 _.to_latest  # unused property (aea/configurations/base.py:442)
 _.to_uri_path  # unused property (aea/configurations/base.py:445)
 _.to_uri_path  # unused property (aea/configurations/base.py:605)
+_._ensure_connected  # unused method (aea/connections/base.py:104)
+_._ensure_valid_envelope_for_external_comms  # unused method (aea/connections/base.py:109)
+_._connect_context  # unused method (aea/connections/base.py:125)
 _.has_crypto_store  # unused property (aea/connections/base.py:138)
 _.from_dir  # unused method (aea/connections/base.py:200)
 MyScaffoldConnection  # unused class (aea/connections/scaffold/connection.py:31)
@@ -103,6 +106,7 @@ _.is_cancelled_by_timeout  # unused method (aea/helpers/exec_timeout.py:51)
 exc_tb  # unused variable (aea/helpers/exec_timeout.py:102)
 exc_type  # unused variable (aea/helpers/exec_timeout.py:102)
 ExecTimeoutSigAlarm  # unused class (aea/helpers/exec_timeout.py:138)
+envelope_from_bytes  # unused function (aea/helpers/file_lock.py:112)
 LOCK_SH  # unused variable (aea/helpers/file_lock.py:32)
 LOCK_NB  # unused variable (aea/helpers/file_lock.py:33)
 _.filesize  # unused attribute (aea/helpers/ipfs/base.py:92)
@@ -129,6 +133,7 @@ _.counterparty_payable_amount_incl_fee  # unused property (aea/helpers/transacti
 _.sender_fee  # unused property (aea/helpers/transaction/base.py:673)
 _.counterparty_fee  # unused property (aea/helpers/transaction/base.py:679)
 _.is_connecting  # unused attribute (aea/multiplexer.py:53)
+_.put_message  # unused method (aea/multiplexer.py:821)
 _.has_to  # unused property (aea/protocols/base.py:100)
 ProtobufSerializer  # unused class (aea/protocols/base.py:278)
 JSONSerializer  # unused class (aea/protocols/base.py:304)
@@ -147,6 +152,7 @@ _.remove_skill  # unused method (aea/registries/resources.py:269)
 _.get_all_handlers  # unused method (aea/registries/resources.py:309)
 _.get_behaviour  # unused method (aea/registries/resources.py:318)
 _.get_behaviours  # unused method (aea/registries/resources.py:331)
+PUBLIC_ID  # unused variable (aea/skills/__init__.py:25)
 _.agent_addresses  # unused property (aea/skills/base.py:154)
 _.from_dir  # unused method (aea/skills/base.py:683)
 CyclicBehaviour  # unused class (aea/skills/behaviours.py:57)
@@ -213,3 +219,5 @@ _.add_agent  # unused method (aea/manager.py:291)
 _.start_all_agents  # unused method (aea/manager.py:396)
 _.get_agent_alias  # unused method (aea/manager.py:486)
 _.DEFAULT_PYPI_INDEX_URL  # unused variable (aea/configurations/base.py:85)
+AEARunner  # unused class (aea/runner.py:84)
+_.join_thread  # unused method (aea/helpers/multiple_executor.py:430)
