@@ -22,7 +22,7 @@
 import logging
 from typing import Dict, FrozenSet, Optional, Set, Tuple, Union, cast
 
-from aea.configurations.base import ProtocolId
+from aea.configurations.base import PublicId
 from aea.exceptions import AEAEnforceError, enforce
 from aea.protocols.base import Message
 
@@ -37,7 +37,7 @@ DEFAULT_BODY_SIZE = 4
 class TProtocolNoCtMessage(Message):
     """A protocol for testing purposes."""
 
-    protocol_id = ProtocolId.from_str("fetchai/t_protocol_no_ct:0.1.0")
+    protocol_id = PublicId.from_str("fetchai/t_protocol_no_ct:0.1.0")
 
     class Performative(Message.Performative):
         """Performatives for the t_protocol_no_ct protocol."""
@@ -474,7 +474,7 @@ class TProtocolNoCtMessage(Message):
             )
 
             # Check correct contents
-            actual_nb_of_contents = len(self.body) - DEFAULT_BODY_SIZE
+            actual_nb_of_contents = len(self._body) - DEFAULT_BODY_SIZE
             expected_nb_of_contents = 0
             if self.performative == TProtocolNoCtMessage.Performative.PERFORMATIVE_PT:
                 expected_nb_of_contents = 5
