@@ -21,6 +21,8 @@
 
 from typing import Any, Dict, cast
 
+from aea.mail.base_pb2 import DialogueMessage
+from aea.mail.base_pb2 import Message as ProtobufMessage
 from aea.protocols.base import Message, Serializer
 
 from tests.data.generator.t_protocol_no_ct import t_protocol_no_ct_pb2
@@ -39,12 +41,15 @@ class TProtocolNoCtSerializer(Serializer):
         :return: the bytes.
         """
         msg = cast(TProtocolNoCtMessage, msg)
+        message_pb = ProtobufMessage()
+        dialogue_message_pb = DialogueMessage()
         t_protocol_no_ct_msg = t_protocol_no_ct_pb2.TProtocolNoCtMessage()
-        t_protocol_no_ct_msg.message_id = msg.message_id
+
+        dialogue_message_pb.message_id = msg.message_id
         dialogue_reference = msg.dialogue_reference
-        t_protocol_no_ct_msg.dialogue_starter_reference = dialogue_reference[0]
-        t_protocol_no_ct_msg.dialogue_responder_reference = dialogue_reference[1]
-        t_protocol_no_ct_msg.target = msg.target
+        dialogue_message_pb.dialogue_starter_reference = dialogue_reference[0]
+        dialogue_message_pb.dialogue_responder_reference = dialogue_reference[1]
+        dialogue_message_pb.target = msg.target
 
         performative_id = msg.performative
         if performative_id == TProtocolNoCtMessage.Performative.PERFORMATIVE_PT:
@@ -257,8 +262,11 @@ class TProtocolNoCtSerializer(Serializer):
         else:
             raise ValueError("Performative not valid: {}".format(performative_id))
 
-        t_protocol_no_ct_bytes = t_protocol_no_ct_msg.SerializeToString()
-        return t_protocol_no_ct_bytes
+        dialogue_message_pb.content = t_protocol_no_ct_msg.SerializeToString()
+
+        message_pb.dialogue_message.CopyFrom(dialogue_message_pb)
+        message_bytes = message_pb.SerializeToString()
+        return message_bytes
 
     @staticmethod
     def decode(obj: bytes) -> Message:
@@ -268,15 +276,17 @@ class TProtocolNoCtSerializer(Serializer):
         :param obj: the bytes object.
         :return: the 'TProtocolNoCt' message.
         """
+        message_pb = ProtobufMessage()
         t_protocol_no_ct_pb = t_protocol_no_ct_pb2.TProtocolNoCtMessage()
-        t_protocol_no_ct_pb.ParseFromString(obj)
-        message_id = t_protocol_no_ct_pb.message_id
+        message_pb.ParseFromString(obj)
+        message_id = message_pb.dialogue_message.message_id
         dialogue_reference = (
-            t_protocol_no_ct_pb.dialogue_starter_reference,
-            t_protocol_no_ct_pb.dialogue_responder_reference,
+            message_pb.dialogue_message.dialogue_starter_reference,
+            message_pb.dialogue_message.dialogue_responder_reference,
         )
-        target = t_protocol_no_ct_pb.target
+        target = message_pb.dialogue_message.target
 
+        t_protocol_no_ct_pb.ParseFromString(message_pb.dialogue_message.content)
         performative = t_protocol_no_ct_pb.WhichOneof("performative")
         performative_id = TProtocolNoCtMessage.Performative(str(performative))
         performative_content = dict()  # type: Dict[str, Any]
