@@ -29,10 +29,9 @@ from unittest.mock import patch
 
 import pytest
 
-from aea import AEA_DIR
 from aea.aea import AEA
 from aea.aea_builder import AEABuilder
-from aea.configurations.base import PublicId, SkillConfig
+from aea.configurations.base import SkillConfig
 from aea.configurations.constants import DEFAULT_LEDGER, DEFAULT_PRIVATE_KEY_FILE
 from aea.crypto.wallet import Wallet
 from aea.exceptions import AEAException
@@ -40,13 +39,13 @@ from aea.helpers.exception_policy import ExceptionPolicyEnum
 from aea.identity.base import Identity
 from aea.mail.base import Envelope
 from aea.protocols.base import Protocol
-from aea.protocols.default.message import DefaultMessage
-from aea.protocols.default.serialization import DefaultSerializer
 from aea.registries.resources import Resources
 from aea.runtime import RuntimeStates, _StopRuntime
 from aea.skills.base import Skill, SkillContext
 
-from packages.fetchai.connections.local.connection import LocalNode
+from packages.fetchai.connections.local.connection import LocalNode, OEFLocalConnection
+from packages.fetchai.protocols.default.message import DefaultMessage
+from packages.fetchai.protocols.default.serialization import DefaultSerializer
 from packages.fetchai.protocols.fipa.message import FipaMessage
 
 from tests.common.utils import (
@@ -160,12 +159,10 @@ def test_react():
         builder.add_connection(
             Path(ROOT_DIR, "packages", "fetchai", "connections", "local")
         )
-        local_connection_id = PublicId.from_str("fetchai/local:0.10.0")
+        local_connection_id = OEFLocalConnection.connection_id
         builder.set_default_connection(local_connection_id)
         builder.add_skill(Path(CUR_PATH, "data", "dummy_skill"))
-        agent = builder.build(
-            connection_ids=[PublicId.from_str("fetchai/local:0.10.0")]
-        )
+        agent = builder.build(connection_ids=[local_connection_id])
         # This is a temporary workaround to feed the local node to the OEF Local connection
         # TODO remove it.
         local_connection = agent.resources.get_connection(local_connection_id)
@@ -216,10 +213,10 @@ def test_handle():
         builder.add_connection(
             Path(ROOT_DIR, "packages", "fetchai", "connections", "local")
         )
-        local_connection_id = PublicId.from_str("fetchai/local:0.10.0")
+        local_connection_id = OEFLocalConnection.connection_id
         builder.set_default_connection(local_connection_id)
         builder.add_skill(Path(CUR_PATH, "data", "dummy_skill"))
-        aea = builder.build(connection_ids=[PublicId.from_str("fetchai/local:0.10.0")])
+        aea = builder.build(connection_ids=[local_connection_id])
         # This is a temporary workaround to feed the local node to the OEF Local connection
         # TODO remove it.
         local_connection = aea.resources.get_connection(local_connection_id)
@@ -314,10 +311,10 @@ def test_initialize_aea_programmatically():
         builder.add_connection(
             Path(ROOT_DIR, "packages", "fetchai", "connections", "local")
         )
-        local_connection_id = PublicId.from_str("fetchai/local:0.10.0")
+        local_connection_id = OEFLocalConnection.connection_id
         builder.set_default_connection(local_connection_id)
         builder.add_skill(Path(CUR_PATH, "data", "dummy_skill"))
-        aea = builder.build(connection_ids=[PublicId.from_str("fetchai/local:0.10.0")])
+        aea = builder.build(connection_ids=[local_connection_id])
         local_connection = aea.resources.get_connection(local_connection_id)
         local_connection._local_node = node
 
@@ -396,13 +393,14 @@ def test_initialize_aea_programmatically_build_resources():
             )
 
             default_protocol = Protocol.from_dir(
-                str(Path(AEA_DIR, "protocols", "default"))
+                str(Path("packages", "fetchai", "protocols", "default"))
             )
             resources.add_protocol(default_protocol)
             resources.add_connection(connection)
 
             error_skill = Skill.from_dir(
-                str(Path(AEA_DIR, "skills", "error")), agent_context=aea.context
+                str(Path("packages", "fetchai", "skills", "error")),
+                agent_context=aea.context,
             )
             dummy_skill = Skill.from_dir(
                 str(Path(CUR_PATH, "data", "dummy_skill")), agent_context=aea.context
@@ -493,7 +491,7 @@ def test_add_behaviour_dynamically():
     with run_in_thread(agent.start, timeout=5, on_exit=agent.stop):
         wait_for_condition(lambda: agent.is_running, timeout=10)
 
-        dummy_skill_id = PublicId("dummy_author", "dummy", "0.1.0")
+        dummy_skill_id = DUMMY_SKILL_PUBLIC_ID
         dummy_skill = agent.resources.get_skill(dummy_skill_id)
 
         wait_for_condition(lambda: dummy_skill is not None, timeout=10)
