@@ -45,7 +45,11 @@ class TestRemoveSkillWithPublicId:
         cls.agent_name = "myagent"
         cls.cwd = os.getcwd()
         cls.t = tempfile.mkdtemp()
-        cls.skill_id = "fetchai/gym:0.9.0"
+        dir_path = Path("packages")
+        tmp_dir = cls.t / dir_path
+        src_dir = cls.cwd / Path(ROOT_DIR, dir_path)
+        shutil.copytree(str(src_dir), str(tmp_dir))
+        cls.skill_id = "fetchai/gym:0.10.0"
         cls.skill_name = "gym"
 
         os.chdir(cls.t)
@@ -114,7 +118,11 @@ class TestRemoveSkillFailsWhenSkillIsNotSupported:
         cls.agent_name = "myagent"
         cls.cwd = os.getcwd()
         cls.t = tempfile.mkdtemp()
-        cls.skill_id = "fetchai/gym:0.9.0"
+        dir_path = Path("packages")
+        tmp_dir = cls.t / dir_path
+        src_dir = cls.cwd / Path(ROOT_DIR, dir_path)
+        shutil.copytree(str(src_dir), str(tmp_dir))
+        cls.skill_id = "fetchai/gym:0.10.0"
 
         os.chdir(cls.t)
         result = cls.runner.invoke(
@@ -168,7 +176,11 @@ class TestRemoveSkillFailsWhenExceptionOccurs:
         cls.agent_name = "myagent"
         cls.cwd = os.getcwd()
         cls.t = tempfile.mkdtemp()
-        cls.skill_id = "fetchai/gym:0.9.0"
+        dir_path = Path("packages")
+        tmp_dir = cls.t / dir_path
+        src_dir = cls.cwd / Path(ROOT_DIR, dir_path)
+        shutil.copytree(str(src_dir), str(tmp_dir))
+        cls.skill_id = "fetchai/gym:0.10.0"
         cls.skill_name = "gym"
 
         os.chdir(cls.t)
