@@ -28,9 +28,9 @@ from aea.configurations.base import PublicId
 from aea.mail.base import Envelope, EnvelopeContext, ProtobufEnvelopeSerializer, URI
 from aea.multiplexer import InBox, Multiplexer, OutBox
 from aea.protocols.base import Message
-from aea.protocols.default.message import DefaultMessage
 
 from packages.fetchai.connections.local.connection import LocalNode
+from packages.fetchai.protocols.default.message import DefaultMessage
 
 from tests.conftest import (
     UNKNOWN_PROTOCOL_PUBLIC_ID,
