@@ -28,10 +28,10 @@ import pytest
 import aea
 from aea.helpers.search.models import Description
 from aea.helpers.transaction.base import Terms, TransactionDigest, TransactionReceipt
-from aea.protocols.default.message import DefaultMessage
 from aea.protocols.dialogue.base import DialogueMessage, Dialogues
 from aea.test_tools.test_skill import BaseSkillTestCase, COUNTERPARTY_NAME
 
+from packages.fetchai.protocols.default.message import DefaultMessage
 from packages.fetchai.protocols.fipa.message import FipaMessage
 from packages.fetchai.protocols.ledger_api.message import LedgerApiMessage
 from packages.fetchai.protocols.oef_search.message import OefSearchMessage
