@@ -23,12 +23,15 @@ import time
 from aea.common import Address
 from aea.mail.base import Envelope
 from aea.protocols.base import Message
-from aea.protocols.default.dialogues import DefaultDialogue
-from aea.protocols.default.dialogues import DefaultDialogues as BaseDefaultDialogues
-from aea.protocols.default.message import DefaultMessage
 from aea.protocols.dialogue.base import Dialogue
 from aea.test_tools.test_cases import AEATestCaseEmpty
 
+from packages.fetchai.protocols.default.dialogues import DefaultDialogue
+from packages.fetchai.protocols.default.dialogues import (
+    DefaultDialogues as BaseDefaultDialogues,
+)
+from packages.fetchai.protocols.default.message import DefaultMessage
+
 
 class DefaultDialogues(BaseDefaultDialogues):
     """The dialogues class keeps track of all dialogues."""
@@ -65,7 +68,7 @@ class TestEchoSkill(AEATestCaseEmpty):
 
     def test_echo(self):
         """Run the echo skill sequence."""
-        self.add_item("skill", "fetchai/echo:0.9.0")
+        self.add_item("skill", "fetchai/echo:0.10.0")
 
         process = self.run_agent()
         is_running = self.is_running(process)
