@@ -27,7 +27,7 @@ from threading import Thread
 from typing import Optional, cast
 
 from aea.aea_builder import AEABuilder
-from aea.configurations.base import ComponentType, ProtocolId, PublicId, SkillConfig
+from aea.configurations.base import ComponentType, PublicId, SkillConfig
 from aea.configurations.constants import DEFAULT_LEDGER, DEFAULT_PRIVATE_KEY_FILE
 from aea.crypto.helpers import create_private_key
 from aea.protocols.base import Address, Message
@@ -61,6 +61,7 @@ class TestEndToEndGenerator(UseOef):
         """Set the test up."""
         cls.cwd = os.getcwd()
         cls.t = tempfile.mkdtemp()
+        shutil.copytree(Path(ROOT_DIR, "packages"), Path(cls.t, "packages"))
         os.chdir(cls.t)
         cls.private_key_path_1 = os.path.join(cls.t, DEFAULT_PRIVATE_KEY_FILE + "_1")
         cls.private_key_path_2 = os.path.join(cls.t, DEFAULT_PRIVATE_KEY_FILE + "_2")
@@ -75,7 +76,7 @@ class TestEndToEndGenerator(UseOef):
         builder_1.set_name(agent_name_1)
         builder_1.add_private_key(DEFAULT_LEDGER, self.private_key_path_1)
         builder_1.set_default_ledger(DEFAULT_LEDGER)
-        builder_1.set_default_connection(PublicId.from_str("fetchai/oef:0.11.0"))
+        builder_1.set_default_connection(PublicId.from_str("fetchai/oef:0.12.0"))
         builder_1.add_protocol(
             Path(ROOT_DIR, "packages", "fetchai", "protocols", "fipa")
         )
@@ -101,7 +102,7 @@ class TestEndToEndGenerator(UseOef):
         builder_2.add_protocol(
             Path(ROOT_DIR, "packages", "fetchai", "protocols", "oef_search")
         )
-        builder_2.set_default_connection(PublicId.from_str("fetchai/oef:0.11.0"))
+        builder_2.set_default_connection(PublicId.from_str("fetchai/oef:0.12.0"))
         builder_2.add_component(
             ComponentType.PROTOCOL,
             Path(PATH_TO_T_PROTOCOL),
@@ -113,10 +114,10 @@ class TestEndToEndGenerator(UseOef):
 
         # create AEAs
         aea_1 = builder_1.build(
-            connection_ids=[PublicId.from_str("fetchai/oef:0.11.0")]
+            connection_ids=[PublicId.from_str("fetchai/oef:0.12.0")]
         )
         aea_2 = builder_2.build(
-            connection_ids=[PublicId.from_str("fetchai/oef:0.11.0")]
+            connection_ids=[PublicId.from_str("fetchai/oef:0.12.0")]
         )
 
         # dialogues
@@ -312,7 +313,7 @@ class TestEndToEndGenerator(UseOef):
 class Agent1Handler(Handler):
     """The handler for agent 1."""
 
-    SUPPORTED_PROTOCOL = TProtocolMessage.protocol_id  # type: Optional[ProtocolId]
+    SUPPORTED_PROTOCOL = TProtocolMessage.protocol_id  # type: Optional[PublicId]
 
     def __init__(self, dialogues: TProtocolDialogues, **kwargs):
         """Initialize the handler."""
@@ -347,7 +348,7 @@ class Agent1Handler(Handler):
 class Agent2Handler(Handler):
     """The handler for agent 2."""
 
-    SUPPORTED_PROTOCOL = TProtocolMessage.protocol_id  # type: Optional[ProtocolId]
+    SUPPORTED_PROTOCOL = TProtocolMessage.protocol_id  # type: Optional[PublicId]
 
     def __init__(
         self, message: TProtocolMessage, dialogues: TProtocolDialogues, **kwargs
