@@ -26,12 +26,16 @@ import pytest
 
 from aea.mail.base import Envelope
 from aea.protocols.base import Message
-from aea.protocols.default.dialogues import DefaultDialogue, DefaultDialogues
-from aea.protocols.default.message import DefaultMessage
 from aea.protocols.dialogue.base import Dialogue
 from aea.test_tools.exceptions import AEATestingException
 from aea.test_tools.test_cases import AEATestCase, AEATestCaseEmpty
 
+from packages.fetchai.protocols.default.dialogues import (
+    DefaultDialogue,
+    DefaultDialogues,
+)
+from packages.fetchai.protocols.default.message import DefaultMessage
+
 from tests.conftest import FETCHAI
 from tests.test_cli import test_generate_wealth, test_interact
 
@@ -158,7 +162,7 @@ class TestGenericCases(AEATestCaseEmpty):
     def test_fetch_and_delete(self):
         """Fetch and delete agent from repo."""
         agent_name = "some_agent_for_tests"
-        self.fetch_agent("fetchai/my_first_aea:0.13.0", agent_name)
+        self.fetch_agent("fetchai/my_first_aea:0.14.0", agent_name)
         assert os.path.exists(agent_name)
         self.delete_agents(agent_name)
         assert not os.path.exists(agent_name)
@@ -166,7 +170,7 @@ class TestGenericCases(AEATestCaseEmpty):
     def test_diff(self):
         """Test difference_to_fetched_agent."""
         agent_name = "some_agent_for_tests2"
-        self.fetch_agent("fetchai/my_first_aea:0.13.0", agent_name)
+        self.fetch_agent("fetchai/my_first_aea:0.14.0", agent_name)
         self.run_cli_command(
             "config", "set", "agent.default_ledger", "test_ledger", cwd=agent_name
         )
@@ -175,7 +179,7 @@ class TestGenericCases(AEATestCaseEmpty):
         )
         assert b"test_ledger" in result.stdout_bytes
         diff = self.difference_to_fetched_agent(
-            "fetchai/my_first_aea:0.13.0", agent_name
+            "fetchai/my_first_aea:0.14.0", agent_name
         )
         assert diff
         assert "test_ledger" in diff[1]
@@ -183,9 +187,9 @@ class TestGenericCases(AEATestCaseEmpty):
     def test_no_diff(self):
         """Test no difference for two aea configs."""
         agent_name = "some_agent_for_tests3"
-        self.fetch_agent("fetchai/my_first_aea:0.13.0", agent_name)
+        self.fetch_agent("fetchai/my_first_aea:0.14.0", agent_name)
         diff = self.difference_to_fetched_agent(
-            "fetchai/my_first_aea:0.13.0", agent_name
+            "fetchai/my_first_aea:0.14.0", agent_name
         )
         assert not diff
 
@@ -219,15 +223,27 @@ class TestGenericCases(AEATestCaseEmpty):
             assert f.read() == "hi"
 
 
-class TestAddAndRejectComponent(AEATestCaseEmpty):
+class TestAddAndEjectComponent(AEATestCaseEmpty):
     """Test add/reject components."""
 
     def test_add_and_eject(self):
         """Test add/reject components."""
-        result = self.add_item("skill", "fetchai/echo:0.9.0", local=True)
+        result = self.add_item("skill", "fetchai/echo:0.10.0", local=True)
         assert result.exit_code == 0
 
-        result = self.eject_item("skill", "fetchai/echo:0.9.0")
+        result = self.eject_item("skill", "fetchai/echo:0.10.0")
+        assert result.exit_code == 0
+
+
+class TestAddAndRemoveComponent(AEATestCaseEmpty):
+    """Test add/remove components."""
+
+    def test_add_and_eject(self):
+        """Test add/reject components."""
+        result = self.add_item("skill", "fetchai/echo:0.10.0", local=True)
+        assert result.exit_code == 0
+
+        result = self.remove_item("skill", "fetchai/echo:0.10.0")
         assert result.exit_code == 0
 
 
@@ -274,7 +290,7 @@ class TestSendReceiveEnvelopesSkill(AEATestCaseEmpty):
 
     def test_send_receive_envelope(self):
         """Run the echo skill sequence."""
-        self.add_item("skill", "fetchai/echo:0.9.0")
+        self.add_item("skill", "fetchai/echo:0.10.0")
 
         process = self.run_agent()
         is_running = self.is_running(process)
